@@ -32,15 +32,16 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
-    """ off, due to cloudflare v2 captcha
     def anichin(self, link: str):
+        """works with batch, bd, and single eps link
+        https://anichin.vip/soul-land-season-2-episode-226-252-subtitle-indonesia/
+        """
         try:
             url = f"{self.base_url}/anime/anichin?link={link}"
             response = get(url, timeout=15).json()
             return dumps(response, indent=2)
         except Exception as e:
             return "An error occured report on @YBotsSupport\n\n{}".format(e)
-    """
 
     def kusonime(self, link: str):
         """works with batch, bd, and single eps link
@@ -135,6 +136,18 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
+    def masterkomik(self, link: str):
+        """work with list and single chapter
+        list: https://masterkomik.com/manga/max-level-player/
+        single: https://masterkomik.com/max-level-player-chapter-07/
+        """
+        try:
+            url = f"{self.base_url}/manga/masterkomik?link={link}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
     def doujindesu(self, link: str):
         """works with list and single chapter
         list: https://212.32.226.234/manga/i-cant-stand-it-ajumma/
@@ -158,6 +171,38 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
+    def sukidesuost(self, link: str):
+        try:
+            url = f"{self.base_url}/music/sukidesuost?link={link}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
+    def google(self, query: str):
+        try:
+            url = f"{self.base_url}/google/search?query={query}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
+    def lk21(self, query: str):
+        try:
+            url = f"{self.base_url}/lk21/search?title={query}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
+    def sukidesuost_search(self, query: str, page: int):
+        try:
+            url = f"{self.base_url}/music/sukidesuost/search?query={query}&page={page}"
+            response = get(url, timeout=15).json()
+            return dumps(response, indent=2)
+        except Exception as e:
+            return f"An error occured report on @YBotsSupport\n\n{e}"
+
     def anipics(self, category: str, tags: str):
         """
         Available category: nsfw
@@ -270,22 +315,6 @@ class WibuAPI:
         except Exception as e:
             return f"An error occured report on @YBotsSupport\n\n{e}"
 
-    def google(self, query: str):
-        try:
-            url = f"{self.base_url}/google/search?query={query}"
-            response = get(url, timeout=15).json()
-            return dumps(response, indent=2)
-        except Exception as e:
-            return f"An error occured report on @YBotsSupport\n\n{e}"
-
-    def lk21(self, query: str):
-        try:
-            url = f"{self.base_url}/lk21/search?title={query}"
-            response = get(url, timeout=15).json()
-            return dumps(response, indent=2)
-        except Exception as e:
-            return f"An error occured report on @YBotsSupport\n\n{e}"
-
     def ud(self, query: str):
         try:
             url = f"{self.base_url}/etc/ud?query={query}"
